@@ -2,6 +2,7 @@ package Net::Flotum::API::ExceptionHandler;
 use strict;
 use warnings;
 use utf8;
+use JSON::MaybeXS;
 
 require Exporter;
 our @ISA    = qw(Exporter);
@@ -41,6 +42,13 @@ sub request_with_retries {
             $logger->error($msg);
             die "$msg\n";
         }
+        elsif ( $res->code == 400 && ref $obj eq 'ARRAY' ) {
+            my $msg = "Invalid data:\n";
+            $msg .= encode_json($_) . "\n" for @{$obj};
+            $logger->error( &log_error_txt( $@, $req, $res ) );
+            $logger->error($msg);
+            die $obj;
+        }
 
         $logger->error( &log_error_txt( $@, $req, $res ) );
 
